==> haskell-pandoc-server-0.1.0.5-157-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-hh8WrheEfcG6zAGvpcUSZ
key:                  pandoc-server-0.1.0.5-hh8WrheEfcG6zAGvpcUSZ
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  1e1fd9791bcfc2baebed38c03691dd0c
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-hh8WrheEfcG6zAGvpcUSZ
depends:
    aeson-2.1.2.1-KaceSWeAWkBK9urIr7RMHq base-4.17.2.1
    base64-bytestring-1.2.1.0-3I8EkZDRuR97orcJ5EVOv5
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    doctemplates-0.11-LPsHVRePH8q4gHJW06R6Uj
    pandoc-3.1.12.1-L1328oe5vHxB0trzQXjAZd
    pandoc-types-1.23.1-KPxfYu3FkWmKFcTk62d0c7
    servant-server-0.20.2-K2Yt5YyiJLz2bIWSF8oiBO
    skylighting-0.14.1.1-7KLpK0k8Ts142ZUaLtuUmm text-2.0.2
    unicode-collation-0.1.3.6-Gdhc9vdcr3hH5saTrR2TbS
    wai-3.2.4-JjfNpwYIsY661HSR3DMIkW
    wai-cors-0.2.7-FqbnIOmLJfxH2td6Kkv6Mb

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-server-0.1.0.5-158-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.5
visibility:           public
id:                   pandoc-server-0.1.0.5-BLcLBeAtR6n2WqC17ivNm7
key:                  pandoc-server-0.1.0.5-BLcLBeAtR6n2WqC17ivNm7
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  6a480ddc552667e50464e09bd889ab65
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-server-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.5-BLcLBeAtR6n2WqC17ivNm7
depends:
    aeson-2.1.2.1-KaceSWeAWkBK9urIr7RMHq base-4.17.2.1
    base64-bytestring-1.2.1.0-3I8EkZDRuR97orcJ5EVOv5
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    doctemplates-0.11-LPsHVRePH8q4gHJW06R6Uj
    pandoc-3.1.12.1-ErXzYFodxy69dVRDXTlMed
    pandoc-types-1.23.1-KPxfYu3FkWmKFcTk62d0c7
    servant-server-0.20.2-K2Yt5YyiJLz2bIWSF8oiBO
    skylighting-0.14.1.1-7KLpK0k8Ts142ZUaLtuUmm text-2.0.2
    unicode-collation-0.1.3.6-Gdhc9vdcr3hH5saTrR2TbS
    wai-3.2.4-JjfNpwYIsY661HSR3DMIkW
    wai-cors-0.2.7-FqbnIOmLJfxH2td6Kkv6Mb

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
